==> haskell-descriptive-0.9.5-27-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-descriptive.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: descriptive
version: 0.9.5
id: descriptive-0.9.5-AMVlqClK2xxL5MUdbbTts7
key: descriptive-0.9.5-AMVlqClK2xxL5MUdbbTts7
license: BSD-3-Clause
copyright: 2015 Chris Done
maintainer: chrisdone@gmail.com
author: Chris Done
stability: Experimental
homepage: https://github.com/chrisdone/descriptive
synopsis: Self-describing consumers/parsers; forms, cmd-line args, JSON, etc.
description:
    Self-describing consumers/parsers. See the README.md for more information. It is currently EXPERIMENTAL.
category: Parsing
abi: 530a7bca131f630c2696d70ecd40ad2a
exposed: True
exposed-modules:
    Descriptive Descriptive.Char Descriptive.Form Descriptive.Formlet
    Descriptive.JSON Descriptive.Options
hidden-modules: Descriptive.Internal
import-dirs: /usr/lib/ghc-8.6.4/site-local/descriptive-0.9.5
library-dirs: /usr/lib/ghc-8.6.4/site-local/descriptive-0.9.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/descriptive-0.9.5
hs-libraries: HSdescriptive-0.9.5-AMVlqClK2xxL5MUdbbTts7
depends:
    aeson-1.4.2.0-3p7goNB3q4s1JbMrIJBuLL base-4.12.0.0
    bifunctors-5.5.3-Am0ITuGRs0n6u4i0spWxI containers-0.6.0.1 mtl-2.2.2
    scientific-0.3.6.2-BVEhLkswVxa6jxFFJ9XwaR text-1.2.3.1
    transformers-0.5.6.2 vector-0.12.0.2-AoZ9EwUsgIW1yrOc105QXH
haddock-interfaces: /usr/share/doc/haskell-descriptive/html/descriptive.haddock
haddock-html: /usr/share/doc/haskell-descriptive/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-descriptive-0.9.5-28-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-descriptive.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: descriptive
version: 0.9.5
id: descriptive-0.9.5-EmwqhKdeIflJ6mQwphrsas
key: descriptive-0.9.5-EmwqhKdeIflJ6mQwphrsas
license: BSD-3-Clause
copyright: 2015 Chris Done
maintainer: chrisdone@gmail.com
author: Chris Done
stability: Experimental
homepage: https://github.com/chrisdone/descriptive
synopsis: Self-describing consumers/parsers; forms, cmd-line args, JSON, etc.
description:
    Self-describing consumers/parsers. See the README.md for more information. It is currently EXPERIMENTAL.
category: Parsing
abi: e15a907ed2149b490f5158e20b041468
exposed: True
exposed-modules:
    Descriptive Descriptive.Char Descriptive.Form Descriptive.Formlet
    Descriptive.JSON Descriptive.Options
hidden-modules: Descriptive.Internal
import-dirs: /usr/lib/ghc-8.6.4/site-local/descriptive-0.9.5
library-dirs: /usr/lib/ghc-8.6.4/site-local/descriptive-0.9.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/descriptive-0.9.5
hs-libraries: HSdescriptive-0.9.5-EmwqhKdeIflJ6mQwphrsas
depends:
    aeson-1.4.2.0-Avxlg2iWl9mA2BcbnSAv1Y base-4.12.0.0
    bifunctors-5.5.3-Am0ITuGRs0n6u4i0spWxI containers-0.6.0.1 mtl-2.2.2
    scientific-0.3.6.2-BVEhLkswVxa6jxFFJ9XwaR text-1.2.3.1
    transformers-0.5.6.2 vector-0.12.0.2-AoZ9EwUsgIW1yrOc105QXH
haddock-interfaces: /usr/share/doc/haskell-descriptive/html/descriptive.haddock
haddock-html: /usr/share/doc/haskell-descriptive/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
